@@ -9,6 +9,7 @@ r<-citep("10.1007/s10522-006-9073-3")
 r<-citep("10.1016/j.jtbi.2009.01.023")
 r<-citep("10.3389/fpubh.2014.00228")
 r<-citep("10.1002/gepi.22058")
+r<-citep("10.3389/fpubh.2016.00003")
 write.bibtex(file="references.bib")
 
 ## ----eval=FALSE----------------------------------------------------------
@@ -161,6 +162,7 @@ opt.par
 
 n <- 10
 data <- simdata_time_dep(N=n)
+# Temporarily commented below
 # Estimation:
 opt.par <- spm_time_dep(data, frm = list(at="a", f1t="f1", Qt="Q", ft="0", bt="b", mu0t="mu0"), 
                         start=list(a=-0.05, f1=80, Q=2e-08, b=5, mu0=0.001), 
@@ -168,6 +170,13 @@ opt.par <- spm_time_dep(data, frm = list(at="a", f1t="f1", Qt="Q", ft="0", bt="b
 opt.par
 
 
+## ------------------------------------------------------------------------
+library(stpm) 
+dat <- simdata_cont(N=500)
+colnames(dat) <- c("id", "xi", "t1", "t2", "y", "y.next")
+res <- spm_con_1d(as.data.frame(dat), a=-0.05, b=2, q=1e-8, f=80, f1=90, mu0=1e-3, theta=0.08)
+res
+
 ## ------------------------------------------------------------------------
 library(stpm)
 data <- simdata_discr(N=10)
@@ -210,8 +219,8 @@ head(ex_data$gene_data)
 res <- spm_con_1d_g(spm_data=ex_data$spm_data, 
                     gene_data=ex_data$gene_data, 
                     a = -0.02, b=0.2, q=0.01, f=3, f1=3, mu0=0.01, theta=1e-05, 
-                    upper=c(-0.01,3,0.1,10,10,0.1,1e-05), lower=c(-1,0.01,0.00001,1,1,0.001,1e-05), 
-                    effect=c('q'))
+                    upper=c(-0.01,3,0.1,10,10,0.1,1e-05), lower=c(-1,0.01,0.00001,1,1,0.001,1e-07), 
+                    effect=c('q'), method = "tnewton")
 res
 
 ## ---- eval=TRUE, message=FALSE-------------------------------------------
@@ -273,3 +282,75 @@ head(incomplete.data)
 ###### Look at the imputed data #####
 head(imp.data)
 
+## ------------------------------------------------------------------------
+#library(stpm)
+#data <- simdata_discr(N=100, format="long")
+#res <- spm_discrete(data)
+#splitted <- split(data, data$id)
+#df <- data.frame()
+#lapply(1:100, function(i) {df<<-rbind(df,splitted[[i]][dim(splitted[[i]])[1],c("id", "xi", "t1", "y1")])})
+#names(df) <- c("id", "xi", "t", "y")
+#predicted <- predict(object=res, data=df, dt=3)
+#head(predicted)
+
+## ---- eval=FALSE---------------------------------------------------------
+#  library(stpm)
+#  n <- 1000
+#  
+#  # Data simulation:
+#  data <- simdata_time_dep(N=n, format="long")
+#  head(data)
+#  
+#  # Hypotheses testing
+#  
+#  ## H01
+#  res <- spm_time_dep(data, verbose=F,
+#                      frm = list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0"),
+#                      start=list(a=-0.05, f1=80, Q=1e-8, f=90, b=5, mu0=0.001),
+#                      lb=c(a=-1, f1=30, Q=1e-9, f=10, b=1, mu0=1e-6),
+#                      ub=c(a=0, f1=120, Q=1e-7, f=150, b=10, mu0=1e-2),
+#                      opts = list(algorithm = "NLOPT_LN_NELDERMEAD",
+#                      maxeval = 200, ftol_rel = 1e-12), lrtest="H01")
+#  
+#  res$alternative$lr.test.pval
+#  
+#  ## H02
+#  res <- spm_time_dep(data, verbose=F,
+#                      frm = list(at="a", f1t="f1", Qt="1e-6", ft="f", bt="b", mu0t="mu0"),
+#                      start=list(a=-0.05, f1=80, Q=1e-8, f=90, b=5, mu0=0.001),
+#                      lb=c(a=-1, f1=30, Q=1e-9, f=10, b=1, mu0=1e-6),
+#                      ub=c(a=0, f1=120, Q=1e-7, f=150, b=10, mu0=1e-2),
+#                      opts = list(algorithm = "NLOPT_LN_NELDERMEAD",
+#                      maxeval = 200, ftol_rel = 1e-12), lrtest="H02")
+#  
+#  res$alternative$lr.test.pval
+#  
+#  ## H03
+#  res <- spm_time_dep(data, verbose=F,
+#                      frm = list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0"),
+#                      start=list(a=-0.05, f1=80, Q=1e-8, f=90, b=5, mu0=0.001),
+#                      ub=c(a=0, f1=120, Q=1e-7, f=150, b=10, mu0=1e-2),
+#                      opts = list(algorithm = "NLOPT_LN_NELDERMEAD",
+#                      maxeval = 200, ftol_rel = 1e-12), lrtest="H03")
+#  
+#  res$alternative$lr.test.pval
+#  
+#  ## H04
+#  res <- spm_time_dep(data, verbose=F,
+#                      frm = list(at="a", f1t="120", Qt="Q", ft="f", bt="b", mu0t="mu0"),
+#                      start=list(a=-0.05, f1=80, Q=1e-8, f=90, b=5, mu0=0.001),
+#                      lb=list(a=-1, f1=30, Q=1e-9, f=10, b=1, mu0=1e-6),
+#                      opts = list(algorithm = "NLOPT_LN_NELDERMEAD",
+#                      maxeval = 200, ftol_rel = 1e-12), lrtest="H04")
+#  
+#  res$alternative$lr.test.pval
+#  
+#  ## H05
+#  res <- spm_time_dep(data, verbose=F,
+#                      frm = list(at="-0.1", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0"),
+#                      start=list(a=-0.05, f1=80, Q=1e-8, f=90, b=5, mu0=0.001),
+#                      opts = list(algorithm = "NLOPT_LN_NELDERMEAD",
+#                      maxeval = 200, ftol_rel = 1e-12), lrtest="H05")
+#  
+#  res$alternative$lr.test.pval
+
